@@ -28,7 +28,6 @@ import StringIO
 import sys
 import yaml
 from requests.exceptions import ConnectionError
-from subprocess import Popen, PIPE
 from ferry.table.prettytable import *
 from ferry.options import CmdHelp
 from ferry.install import Installer, FERRY_HOME, GUEST_DOCKER_REPO
@@ -408,11 +407,20 @@ class CLI(object):
                 if e == '.json':
                     json_string = self._read_file_arg(file_path)
                     json_arg = json.loads(json_string)
-                elif e == '.yaml':
+                elif e == '.yaml' or e == '.yml':
                     yaml_file = open(file_path, 'r')
                     json_arg = yaml.load(yaml_file)
-                json_arg['_file_path'] = file_path
+                else:
+                    # This is an unknown file type. We're going to try to
+                    # pretend it is a JSON file and see if we fail.
+                    try:
+                        json_string = self._read_file_arg(file_path)
+                        json_arg = json.loads(json_string)
+                    except ValueError as e:
+                        logging.error("could not load file " + file_path)
+                        exit(1)
 
+                json_arg['_file_path'] = file_path
             json_arg['_file'] = arg
             return self._create_stack(json_arg, args)
         elif(cmd == 'ps'):
@@ -433,6 +441,7 @@ class CLI(object):
             self.installer._clean_web()
             self.installer._stop_docker_daemon(force=True)
             self.installer._reset_ssh_key()
+            self.installer._clean_rules()
             return 'cleaned ferry'
         elif(cmd == 'inspect'):
             return self._inspect_stack(args[0])
