@@ -46,6 +46,10 @@ class DockerFabric(object):
 
         return "%s/%d" % (gw, 32 - cidr)
 
+    def _get_host(self):
+        cmd = "ifconfig eth0 | grep 'inet addr:' | cut -d: -f2 | awk '{ print $1}'"
+        return Popen(cmd, stdout=PIPE, shell=True).stdout.read().strip()
+
     """
     Read the location of the directory containing the keys
     used to communicate with the containers. 
@@ -80,6 +84,10 @@ class DockerFabric(object):
                                        c['args'])
             container.default_user = self.docker_user
             containers.append(container)
+
+        # We should wait for a second to let the ssh server start
+        # on the containers (otherwise sometimes we get a connection refused)
+        time.sleep(2)
         return containers
 
     """
@@ -103,13 +111,29 @@ class DockerFabric(object):
 
             c['default_cmd'] = "/service/sbin/startnode init"
 
+            # Check if we need to forward any ports. 
+            host_map = {}
+            for p in c['ports']:
+                p = str(p)
+                s = p.split(":")
+                if len(s) > 1:
+                    host = s[0]
+                    dest = s[1]
+                else:
+                    host = self.network.random_port()
+                    dest = s[0]
+                host_map[dest] = [{'HostIp' : '0.0.0.0',
+                                   'HostPort' : host}]
+                self.network.forward_rule('0.0.0.0/0', host, ip, dest)
+
             # Start a container with a specific image, in daemon mode,
             # without TTY, and on a specific port
             container = self.cli.run(service_type = c['type'], 
                                      image = c['image'], 
                                      volumes = c['volumes'],
                                      keys = c['keys'], 
-                                     security_group = c['ports'],
+                                     open_ports = host_map.keys(),
+                                     host_map = host_map, 
                                      expose_group = c['exposed'], 
                                      hostname = c['hostname'],
                                      default_cmd = c['default_cmd'],
@@ -152,6 +176,8 @@ class DockerFabric(object):
     """
     def remove(self, containers):
         for c in containers:
+            for p in c.ports.keys():
+                self.network.delete_rule(c.internal_ip, p)
             self.network.free_ip(c.internal_ip)
             self.cli.remove(c.container)
 
