@@ -18,11 +18,6 @@ import logging
 from flask import Flask, request
 from ferry.docker.manager import DockerManager
 
-# Initialize logging
-logging.basicConfig(format='%(asctime)s %(message)s', 
-                    datefmt='%m/%d/%Y %I:%M:%S %p',
-                    level=logging.INFO)
-
 # Initialize Flask
 app = Flask(__name__)
 
@@ -92,8 +87,8 @@ Allocate the backend from a snapshot.
 def _allocate_backend_from_snapshot(payload):
     snapshot_uuid = payload['_file']
     backends = docker.fetch_snapshot_backend(snapshot_uuid)
-    return _allocate_fresh_backend(payload = None,
-                                   backends = backends)
+    return _allocate_backend(payload = None,
+                             backends = backends)
 
 """
 Allocate the backend from a deployment. 
@@ -103,7 +98,7 @@ def _allocate_backend_from_deploy(payload, params=None):
     backends = docker.fetch_deployed_backend(app_uuid, params)
     
     if backends:
-        return _allocate_fresh_backend(payload = None,
+        return _allocate_backend(payload = None,
                                  backends = backends)
 
 """
@@ -114,13 +109,14 @@ def _allocate_backend_from_stopped(payload):
     backends = docker.fetch_stopped_backend(app_uuid)
     
     if backends:
-        return _allocate_fresh_backend(payload = None,
-                                       backends = backends)
+        return _allocate_backend(payload = None,
+                                 backends = backends,
+                                 uuid = app_uuid)
 
 """
 Allocate fresh compute backend. 
 """
-def _allocate_fresh_compute(computes, storage_uuid):
+def _allocate_compute(computes, storage_uuid):
     uuids = []
     for c in computes:
         compute_type = c['personality']
@@ -142,12 +138,24 @@ def _allocate_fresh_compute(computes, storage_uuid):
         uuids.append(compute_uuid)
     return uuids
 
+def _restart_compute(computes):
+    uuids = []
+    for c in computes:
+        service_uuid = c['uuid']
+        containers = c['containers']
+        compute_type = c['type']
+        uuids.append(docker.restart_compute(service_uuid,
+                                            containers, 
+                                            compute_type))
+    return uuids
+
 """
 Allocate a brand new backend
 """
-def _allocate_fresh_backend(payload,
-                            backends=None,
-                            replace=False):
+def _allocate_backend(payload,
+                      backends=None,
+                      replace=False,
+                      uuid=None):
     if not backends:
         if 'backend' in payload:
             backends = payload['backend']
@@ -158,28 +166,39 @@ def _allocate_fresh_backend(payload,
                      'backend' : backends }
     for b in backends:
         storage = b['storage']
-        storage_type = storage['personality']
-        num_instances = int(storage['instances'])
-        layers = []
-        if 'layers' in storage:
-            layers = storage['layers']
 
         args = None
         if 'args' in storage:
             args = storage['args']
 
         # Now create the storage. 
-        storage_uuid = docker.allocate_storage(storage_type = storage_type, 
-                                               num_instances = num_instances,
-                                               layers = layers,
-                                               args = args,
-                                               replace = replace)
+        if not uuid:
+            storage_type = storage['personality']
+            num_instances = int(storage['instances'])
+            layers = []
+            if 'layers' in storage:
+                layers = storage['layers']
+            storage_uuid = docker.allocate_storage(storage_type = storage_type, 
+                                                   num_instances = num_instances,
+                                                   layers = layers,
+                                                   args = args,
+                                                   replace = replace)
+        else:
+            service_uuid = storage['uuid']
+            containers = storage['containers']
+            storage_type = storage['type']
+            storage_uuid = docker.restart_storage(service_uuid,
+                                                  container_info = containers,
+                                                  storage_type = storage_type)
+                                                  
         # Now get the compute information
-        compute_uuid = None
         compute_uuids = []
         if 'compute' in b:
-            computes = b['compute']
-            compute_uuids = _allocate_fresh_compute(computes, storage_uuid)
+            if not uuid:
+                compute_uuids = _allocate_compute(b['compute'], storage_uuid)
+            else:
+                compute_uuids = _restart_compute(b['compute'])
+
         backend_info['uuids'].append( {'storage':storage_uuid,
                                        'compute':compute_uuids} )
     return backend_info
@@ -201,10 +220,15 @@ def _allocate_connectors(payload, backend_info):
             if 'args' in c:
                 args = c['args']
 
+            ports = []
+            if 'ports' in c:
+                ports = c['ports']
+
             connector_info.append(docker.allocate_connector(connector_type = connector_type,
                                                             backend = backend_info, 
                                                             name = connector_name, 
-                                                            args = args))
+                                                            args = args,
+                                                            ports = ports))
     return connector_info
 
 """
@@ -254,7 +278,7 @@ def _allocate_stopped(payload):
 Helper function to allocate and start a new stack. 
 """
 def _allocate_new(payload):
-    backend_info = _allocate_fresh_backend(payload, replace=True)
+    backend_info = _allocate_backend(payload, replace=True)
     connector_info = _allocate_connectors(payload, backend_info['uuids'])
 
     # Register the new cluster. 
